︠1fd296b6-06f5-48b3-a4e2-f7eb2147b78ei︠
%html
<p>Multivariate Limits</p>
<p>John Travis</p>
<p>Mississippi College</p>
<p>Exhibiting graphically whether a given surface has a limit.</p>

︡ee4a2214-0588-414b-8b1c-abad1b04ffb2︡{"html": "<p>Multivariate Limits</p>\n<p>John Travis</p>\n<p>Mississippi College</p>\n<p>Exhibiting graphically whether a given surface has a limit.</p>"}︡
︠2513aaad-f830-4ff6-a6d1-f067a89a84b1ai︠
%hide
%auto
##  An interactive way to demonstrate limits of multivariate functions of the form z = f(x,y)
##
##  John Travis
##  Mississippi College
##  
##  Spring 2011
##

#  Starting point for radius values before collapsing in as R approaches 0.
#  Functions ought to be "reasonable" within a circular domain of radius R surrounding 
#  the desired (x_0,y_0).
var('x,y,z')
Rmin=1/10
Rmax=2
@interact(layout=dict(top=[['f'],['x0'],['y0']], 
bottom=[['R']]))
def _(f=input_box(default=(x^2-y^2)/(x^2+y^2),width=30,label='$f(x)$'),
        R=slider(Rmin,Rmax,1/10,Rmax),
        x0=input_box(0,width=10,label='$x_0$'),
        y0=input_box(0,width=10,label='$y_0$')):

#   converting f to cylindrical coordinates.  
    g(r,t) = f(x=r*cos(t)+x0,y=r*sin(t)+y0)

#   Sage graphing transformation used to see the original surface.
    cylinder = (r*cos(t)+x0,r*sin(t)+y0,z)
    surface = plot3d(g,(t,0,2*pi),(r,1/100,Rmax),transformation=cylinder,opacity=0.2)
    
#   Graph a couple of curves on the surface corresponding to limit as x->0 for y=x^(4/5), and
#   as y->b for x=y^(4/5).  Should make this more robust but perhaps using these obtuse curves
#   could eliminate problems.
    curve_x = parametric_plot3d([x0-t,y0-t^(4/5),f(x=x0-t,y=y0-t^(4/5))],(t,Rmin,Rmax),color='red')
    curve_y = parametric_plot3d([x0+t^(4/5),y0+t,f(x=x0+t^(4/5),y=y0+t)],(t,Rmin,Rmax),color='red')
    limit_x = limit(f(x=x0-t,y=y0-t^(4/5)),t=0,dir='right')
    limit_y = limit(f(x=x0+t^(4/5),y=y0+t),t=0,dir='right')
      
#   Regraph the surface for smaller and smaller radii controlled by the slider.
    collapsing_surface = plot3d(g,(t,0,2*pi),(r,1/100,R),transformation=cylinder,rgbcolor=(0,1,0))
    
    G = surface+collapsing_surface+curve_x+curve_y    
    show(G)
    
    html('Enter $(x_0 ,y_0 )$ above and see what happens as $ R \\rightarrow 0 $.')
    html('The surface has a limit as $(x,y) \\rightarrow $ ('+str(x0)+','+str(y0)+') if the green region collapses to a point.')
    html('The red curves represent a couple of trajectories on the surface.')
    html('If they do not meet, then there is also no limit.')
    html('\n<center><font color="red">$\lim_{(x,?)\\rightarrow(x_0,y_0)} f(x,y) =%s$</font>'%str(limit_x)+'  and <font color="red">$\lim_{(?,y)\\rightarrow(x_0,y_0)} f(x,y) =%s$</font></center>'%str(limit_y))
︡be335c41-9e83-4ab0-b63e-60a836435b1e︡{"html": "<!--notruncate--><div padding=6 id=\"div-interact-10\"> <table width=800px height=20px bgcolor=\"#c5c5c5\"\n                 cellpadding=15><tr><td bgcolor=\"#f9f9f9\" valign=top align=left><table>\n<tr><td colspan=3><table><tr><td align=right><font color=\"black\"><span class=\"math\">f(x)</span>&nbsp;</font></td><td><input type=\"text\" value=\"(x^2 - y^2)/(x^2 + y^2)\" size=30 onchange=\"interact(10, '_interact_.update(\\'10\\', \\'f\\', 15, _interact_.standard_b64decode(\\''+encode64(this.value)+'\\'), globals()); _interact_.recompute(\\'10\\');')\"></input></td>\n</tr><tr><td align=right><font color=\"black\"><span class=\"math\">x_0</span>&nbsp;</font></td><td><input type=\"text\" value=\"0\" size=10 onchange=\"interact(10, '_interact_.update(\\'10\\', \\'x0\\', 17, _interact_.standard_b64decode(\\''+encode64(this.value)+'\\'), globals()); _interact_.recompute(\\'10\\');')\"></input></td>\n</tr><tr><td align=right><font color=\"black\"><span class=\"math\">y_0</span>&nbsp;</font></td><td><input type=\"text\" value=\"0\" size=10 onchange=\"interact(10, '_interact_.update(\\'10\\', \\'y0\\', 18, _interact_.standard_b64decode(\\''+encode64(this.value)+'\\'), globals()); _interact_.recompute(\\'10\\');')\"></input></td>\n</tr></table></td></tr>\n<tr><td></td><td style='width: 100%;'><div id=\"cell-interact-10\"><?__SAGE__START>\n        <table border=0 bgcolor=\"white\" width=100%>\n        <tr><td bgcolor=\"white\" align=left valign=top><pre><?__SAGE__TEXT></pre></td></tr>\n        <tr><td  align=left valign=top><?__SAGE__HTML></td></tr>\n        </table><?__SAGE__END></div></td><td></td></tr>\n<tr><td colspan=3><table><tr><td align=right><font color=\"black\">R&nbsp;</font></td><td><table><tr><td>\n        <div id=\"slider-R-10\" style=\"margin:0px; margin-left: 1.0em; margin-right: 1.0em; width: 15.0em;\"></div>\n        </td><td><font color=\"black\" id=\"slider-R-10-lbl\"></font></td></tr></table><script>(function(){ var values = [\"1/10\",\"1/5\",\"3/10\",\"2/5\",\"1/2\",\"3/5\",\"7/10\",\"4/5\",\"9/10\",\"1\",\"11/10\",\"6/5\",\"13/10\",\"7/5\",\"3/2\",\"8/5\",\"17/10\",\"9/5\",\"19/10\",\"2\"]; setTimeout(function() {\n    $('#slider-R-10').slider({\n        step: 1, min: 0, max: 19, value: 19,\n        change: function (e,ui) { var position = ui.value; if(values!=null) $('#slider-R-10-lbl').text(values[position]); interact(10, '_interact_.update(\\'10\\', \\'R\\', 16, _interact_.standard_b64decode(\\''+encode64(position)+'\\'), globals()); _interact_.recompute(\\'10\\');'); },\n        slide: function(e,ui) { if(values!=null) $('#slider-R-10-lbl').text(values[ui.value]); }\n    });\n    if(values != null) $('#slider-R-10-lbl').text(values[$('#slider-R-10').slider('value')]);\n    }, 1); })();</script></td>\n</tr></table></td></tr>\n</table></td>\n                 </tr></table></div>\n                 "}︡
